<?php

namespace GabrielGciaFdez\Service;

use Doctrine\Common\Annotations\AnnotationRegistry;
use GabrielGciaFdez\Entity\EmailData;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Validator\Validation;

/**
 * Service for validate the example request data
 */
class PhpArchExampleValidator
{
    protected $errors;

    public function __construct()
    {
        $this->errors = null;
        $this->registerConstraints();
    }

    /**
     * Validate the example $data
     *
     * @param  array  $data
     *
     * @return boolean
     */
    public function isValid($data)
    {
        $entity = new EmailData($data);
        $validator = Validation::createValidatorBuilder()
            ->enableAnnotationMapping()
            ->getValidator();

        $this->errors = $validator->validate($entity);

        if (count($this->errors) === 0) {
            return true;
        }

        return false;
    }

    /**
     * Return all validation errors
     *
     * @return string
     */
    public function getErrorMessage()
    {
        return is_null($this->errors) ? "No validation errors" : $this->errors;
    }

    /**
     * Return all validation errors
     *
     * @return object
     */
    public function getErrors()
    {
        return $this->errors;
    }

    private function registerConstraints()
    {
        // Doctrine don't use autoload PHP, we must register it manually
        AnnotationRegistry::registerAutoloadNamespace(
            "Symfony\Component\Validator\Constraint",
            "vendor/symfony/validator"
        );
        AnnotationRegistry::registerAutoloadNamespace(
            "GabrielGciaFdez\Validator\Constraint",
            "src/"
        );
    }
}
